Vue.createApp({
  data() {
    return {
      paths: [
      { fill: '#F6F8FA', d: '', stroke: 'none', tx: 0, ty: 0 },
      { fill: '#B6D9F2', d: '', stroke: 'none', tx: 0, ty: 0 },
      { fill: '#6FC8F3', d: '', stroke: 'none', tx: 0, ty: 0 },
      { fill: '#00B7E9', d: '', stroke: 'none', tx: 0, ty: 0 },
      { fill: '#0F8AC0', d: '', stroke: 'none', tx: 0, ty: 0 },
      { fill: '#0C5F8C', d: '', stroke: 'none', tx: 0, ty: 0 },
      { fill: '#0A3457', d: '', stroke: 'none', tx: 0, ty: 0 }],

      background: '#D8C0A1',
      timeCoef: 0.0001,
      mouseCoef: 10,
      mouseX: 0,
      mouseY: 0,
      mouseTX: 0,
      mouseTY: 0,
      width: 0,
      height: 0,
      cx: 0,
      cy: 0 };

  },
  mounted() {
    this.onResize();
    window.addEventListener('resize', this.onResize);
    this.simplex = new SimplexNoise();
    this.animate();
  },
  unmounted() {
    window.removeEventListener('resize', this.onResize);
  },
  methods: {
    animate() {
      const time = Date.now() * this.timeCoef;
      const n = 120;
      const da = 2 * Math.PI / n;
      const r = Math.min(this.width, this.height) * 0.5;
      const dr = r / (this.paths.length + 1);

      this.mouseTX += (this.mouseX - this.mouseTX) * 0.1;
      this.mouseTY += (this.mouseY - this.mouseTY) * 0.1;

      for (let index = 0; index < this.paths.length; index++) {
        const p = this.paths[index];

        const ti = (index + 1) * this.mouseCoef;
        p.tx = this.mouseTX * ti;
        p.ty = this.mouseTY * ti;

        const points = [];
        const radius = r - (this.paths.length - index) * dr;
        for (let i = 0; i <= n; i++) {
          let x = Math.cos(i * da);
          let y = Math.sin(i * da);
          const nr = radius + this.simplex.noise3D(x, y, time + index * 0.15) * radius * 0.3;
          x = this.cx + p.tx + x * nr;y = this.cy + p.ty + y * nr;
          points.push([x, y]);
        }
        p.d = this.pathd(points);
      }

      requestAnimationFrame(this.animate);
    },
    sstyle(p, i) {
      const c = chroma(p.fill).darken(4).css();
      const shadow = (this.paths.length - i) * 3;
      return 'z-index: ' + (i + 1) * 10 + ';filter: drop-shadow( 0 0 ' + shadow + 'px ' + c + ')';
    },
    pathd(points) {
      const x0 = -this.width;const y0 = -this.height;
      const x1 = this.width * 2;const y1 = this.height * 2;
      let d = `M ${x0},${y0} L ${x0},${y1} L ${x1},${y1} L ${x1},${y0} Z `;

      d += `M ${points[0][0]},${points[0][1]} `;
      for (let i = 1; i < points.length; i++) {
        d += `L ${points[i][0]},${points[i][1]} `;
      }

      return d + 'Z';
    },
    randomColors() {
      const c = chroma.random();
      const cscale = chroma.scale([c.darken(2), chroma.random(), c]);
      this.background = cscale(0).css();
      this.paths.forEach((p, i) => {
        p.fill = cscale((i + 1) / this.paths.length).css();
        p.stroke = chroma(p.fill).darken(1).css();
      });
    },
    onMouseMove(e) {
      this.mouseX = e.clientX / this.width * 2 - 1;
      this.mouseY = e.clientY / this.height * 2 - 1;
    },
    onResize() {
      this.width = window.innerWidth;this.height = window.innerHeight;
      this.cx = this.width / 2;this.cy = this.height / 2;
      this.mouseX = 0;this.mouseY = 0;
      this.mouseCoef = Math.max(this.width, this.height) / 20;
    } } }).

mount('#app');